@@ -8,12 +8,13 @@ https://library.vuforia.com/articles/Solution/How-To-Use-the-Vuforia-Web-Service
 import base64
 import email.utils
 import json
-import os
+import logging
 import uuid
 from http import HTTPStatus
 
 import requests
 from flask import Flask, Response, request
+from pydantic import BaseSettings
 
 from mock_vws._constants import ResultCodes, TargetStatuses
 from mock_vws._database_matchers import get_database_matching_server_keys
@@ -32,13 +33,24 @@ VWS_FLASK_APP = Flask(import_name=__name__)
 VWS_FLASK_APP.config["PROPAGATE_EXCEPTIONS"] = True
 
 
+_LOGGER = logging.getLogger(__name__)
+
+
+class VWSSettings(BaseSettings):
+    """Settings for the VWS Flask app."""
+
+    target_manager_base_url: str
+    processing_time_seconds: float = 0.5
+    vws_host: str = ""
+
+
 def get_all_databases() -> set[VuforiaDatabase]:
     """
     Get all database objects from the task manager back-end.
     """
-    target_manager_base_url = os.environ["TARGET_MANAGER_BASE_URL"]
+    settings = VWSSettings.parse_obj(obj={})
     response = requests.get(
-        url=f"{target_manager_base_url}/databases",
+        url=f"{settings.target_manager_base_url}/databases",
         timeout=30,
     )
     return {
@@ -55,7 +67,9 @@ class ResponseNoContentTypeAdded(Response):
     Some of our responses need to not have a "Content-Type" header.
     """
 
-    default_mimetype = None
+    # The type in Flask is incorrect.
+    # See https://github.com/pallets/flask/pull/5034.
+    default_mimetype = None  # type: ignore[assignment]
 
 
 VWS_FLASK_APP.response_class = ResponseNoContentTypeAdded
@@ -118,9 +132,7 @@ def add_target() -> Response:
     Fake implementation of
     https://library.vuforia.com/articles/Solution/How-To-Use-the-Vuforia-Web-Services-API.html#How-To-Add-a-Target
     """
-    processing_time_seconds = float(
-        os.environ.get("PROCESSING_TIME_SECONDS", "0.5"),
-    )
+    settings = VWSSettings.parse_obj(obj={})
     databases = get_all_databases()
     database = get_database_matching_server_keys(
         request_headers=dict(request.headers),
@@ -145,12 +157,11 @@ def add_target() -> Response:
         width=request_json["width"],
         image_value=base64.b64decode(request_json["image"]),
         active_flag=active_flag,
-        processing_time_seconds=processing_time_seconds,
+        processing_time_seconds=settings.processing_time_seconds,
         application_metadata=request_json.get("application_metadata"),
     )
 
-    target_manager_base_url = os.environ["TARGET_MANAGER_BASE_URL"]
-    databases_url = f"{target_manager_base_url}/databases"
+    databases_url = f"{settings.target_manager_base_url}/databases"
     requests.post(
         url=f"{databases_url}/{database.database_name}/targets",
         json=new_target.to_dict(),
@@ -162,8 +173,10 @@ def add_target() -> Response:
         "content-type": "application/json",
         "server": "envoy",
         "date": date,
-        "x-aws-region": "us-west-2, eu-west-1",
         "x-envoy-upstream-service-time": "5",
+        "strict-transport-security": "max-age=31536000",
+        "x-aws-region": "us-east-2, us-west-2",
+        "x-content-type-options": "nosniff",
     }
 
     body = {
@@ -215,8 +228,10 @@ def get_target(target_id: str) -> Response:
         "content-type": "application/json",
         "server": "envoy",
         "date": date,
-        "x-aws-region": "us-west-2, eu-west-1",
         "x-envoy-upstream-service-time": "5",
+        "strict-transport-security": "max-age=31536000",
+        "x-aws-region": "us-east-2, us-west-2",
+        "x-content-type-options": "nosniff",
     }
     body = {
         "result_code": ResultCodes.SUCCESS.value,
@@ -239,6 +254,7 @@ def delete_target(target_id: str) -> Response:
     Fake implementation of
     https://library.vuforia.com/articles/Solution/How-To-Use-the-Vuforia-Web-Services-API.html#How-To-Delete-a-Target
     """
+    settings = VWSSettings.parse_obj(obj={})
     databases = get_all_databases()
     database = get_database_matching_server_keys(
         request_headers=dict(request.headers),
@@ -256,8 +272,7 @@ def delete_target(target_id: str) -> Response:
     if target.status == TargetStatuses.PROCESSING.value:
         raise TargetStatusProcessing
 
-    target_manager_base_url = os.environ["TARGET_MANAGER_BASE_URL"]
-    databases_url = f"{target_manager_base_url}/databases"
+    databases_url = f"{settings.target_manager_base_url}/databases"
     requests.delete(
         url=f"{databases_url}/{database.database_name}/targets/{target_id}",
         timeout=30,
@@ -272,8 +287,10 @@ def delete_target(target_id: str) -> Response:
         "content-type": "application/json",
         "server": "envoy",
         "date": date,
-        "x-aws-region": "us-west-2, eu-west-1",
         "x-envoy-upstream-service-time": "5",
+        "strict-transport-security": "max-age=31536000",
+        "x-aws-region": "us-east-2, us-west-2",
+        "x-content-type-options": "nosniff",
     }
     return Response(
         status=HTTPStatus.OK,
@@ -323,8 +340,10 @@ def database_summary() -> Response:
         "content-type": "application/json",
         "server": "envoy",
         "date": date,
-        "x-aws-region": "us-west-2, eu-west-1",
         "x-envoy-upstream-service-time": "5",
+        "strict-transport-security": "max-age=31536000",
+        "x-aws-region": "us-east-2, us-west-2",
+        "x-content-type-options": "nosniff",
     }
     return Response(
         status=HTTPStatus.OK,
@@ -372,8 +391,10 @@ def target_summary(target_id: str) -> Response:
         "content-type": "application/json",
         "server": "envoy",
         "date": date,
-        "x-aws-region": "us-west-2, eu-west-1",
         "x-envoy-upstream-service-time": "5",
+        "strict-transport-security": "max-age=31536000",
+        "x-aws-region": "us-east-2, us-west-2",
+        "x-content-type-options": "nosniff",
     }
     return Response(
         status=HTTPStatus.OK,
@@ -425,8 +446,10 @@ def get_duplicates(target_id: str) -> Response:
         "content-type": "application/json",
         "server": "envoy",
         "date": date,
-        "x-aws-region": "us-west-2, eu-west-1",
         "x-envoy-upstream-service-time": "5",
+        "strict-transport-security": "max-age=31536000",
+        "x-aws-region": "us-east-2, us-west-2",
+        "x-content-type-options": "nosniff",
     }
     return Response(
         status=HTTPStatus.OK,
@@ -464,8 +487,10 @@ def target_list() -> Response:
         "content-type": "application/json",
         "server": "envoy",
         "date": date,
-        "x-aws-region": "us-west-2, eu-west-1",
         "x-envoy-upstream-service-time": "5",
+        "strict-transport-security": "max-age=31536000",
+        "x-aws-region": "us-east-2, us-west-2",
+        "x-content-type-options": "nosniff",
     }
     return Response(
         status=HTTPStatus.OK,
@@ -482,6 +507,7 @@ def update_target(target_id: str) -> Response:
     Fake implementation of
     https://library.vuforia.com/articles/Solution/How-To-Use-the-Vuforia-Web-Services-API.html#How-To-Update-a-Target
     """
+    settings = VWSSettings.parse_obj(obj={})
     # We do not use ``request.get_json(force=True)`` because this only works
     # when the content type is given as ``application/json``.
     request_json = json.loads(request.data)
@@ -509,12 +535,24 @@ def update_target(target_id: str) -> Response:
     if "active_flag" in request_json:
         active_flag = request_json["active_flag"]
         if active_flag is None:
+            _LOGGER.warning(
+                msg=(
+                    'The value of "active_flag" was None. '
+                    "This is not allowed. "
+                ),
+            )
             raise Fail(status_code=HTTPStatus.BAD_REQUEST)
         update_values["active_flag"] = active_flag
 
     if "application_metadata" in request_json:
         application_metadata = request_json["application_metadata"]
         if application_metadata is None:
+            _LOGGER.warning(
+                msg=(
+                    'The value of "application_metadata" was None. '
+                    "This is not allowed."
+                ),
+            )
             raise Fail(status_code=HTTPStatus.BAD_REQUEST)
         update_values["application_metadata"] = application_metadata
 
@@ -526,9 +564,8 @@ def update_target(target_id: str) -> Response:
         image = request_json["image"]
         update_values["image"] = image
 
-    target_manager_base_url = os.environ["TARGET_MANAGER_BASE_URL"]
     put_url = (
-        f"{target_manager_base_url}/databases/{database.database_name}/"
+        f"{settings.target_manager_base_url}/databases/{database.database_name}/"
         f"targets/{target_id}"
     )
     requests.put(url=put_url, json=update_values, timeout=30)
@@ -538,8 +575,10 @@ def update_target(target_id: str) -> Response:
         "content-type": "application/json",
         "server": "envoy",
         "date": date,
-        "x-aws-region": "us-west-2, eu-west-1",
         "x-envoy-upstream-service-time": "5",
+        "strict-transport-security": "max-age=31536000",
+        "x-aws-region": "us-east-2, us-west-2",
+        "x-content-type-options": "nosniff",
     }
     body = {
         "result_code": ResultCodes.SUCCESS.value,
@@ -553,4 +592,5 @@ def update_target(target_id: str) -> Response:
 
 
 if __name__ == "__main__":  # pragma: no cover
-    VWS_FLASK_APP.run(debug=True, host=os.environ["VWS_HOST"])
+    SETTINGS = VWSSettings.parse_obj(obj={})
+    VWS_FLASK_APP.run(debug=True, host=SETTINGS.vws_host)
