@@ -3,8 +3,12 @@ Validators for the ``Accept`` header.
 """
 
 
+import logging
+
 from mock_vws._query_validators.exceptions import InvalidAcceptHeader
 
+_LOGGER = logging.getLogger(__name__)
+
 
 def validate_accept_header(request_headers: dict[str, str]) -> None:
     """
@@ -21,4 +25,7 @@ def validate_accept_header(request_headers: dict[str, str]) -> None:
     if accept in ("application/json", "*/*", None):
         return
 
+    _LOGGER.warning(
+        msg="The Accept header is not 'application/json' or '*/*'.",
+    )
     raise InvalidAcceptHeader
