@@ -3,7 +3,9 @@ Validators for the ``Content-Type`` header.
 """
 
 
-import mock_vws._cgi as cgi
+import logging
+from email.message import EmailMessage
+
 from mock_vws._query_validators.exceptions import (
     ImageNotGiven,
     NoBoundaryFound,
@@ -11,6 +13,8 @@ from mock_vws._query_validators.exceptions import (
     UnsupportedMediaType,
 )
 
+_LOGGER = logging.getLogger(__name__)
+
 
 def validate_content_type_header(
     request_headers: dict[str, str],
@@ -32,15 +36,27 @@ def validate_content_type_header(
         NoContentType: The content type header is either empty or not given.
     """
     content_type_header = request_headers.get("Content-Type", "")
-    main_value, pdict = cgi.parse_header(content_type_header)
-    if content_type_header == "":
+    if not content_type_header:
+        _LOGGER.warning(msg="The content type header is empty.")
         raise NoContentType
 
-    if main_value not in ("multipart/form-data", "*/*"):
+    email_message = EmailMessage()
+    email_message["content-type"] = request_headers["Content-Type"]
+    if email_message.get_content_type() not in ("multipart/form-data", "*/*"):
+        _LOGGER.warning(
+            msg=(
+                "The content type header main part is not multipart/form-data."
+            ),
+        )
         raise UnsupportedMediaType
 
-    if "boundary" not in pdict:
+    boundary = email_message.get_boundary()
+    if boundary is None:
+        _LOGGER.warning(
+            msg="The content type header does not contain a boundary.",
+        )
         raise NoBoundaryFound
 
-    if pdict["boundary"].encode() not in request_body:
+    if boundary.encode() not in request_body:
+        _LOGGER.warning(msg="The boundary is not in the request body.")
         raise ImageNotGiven
