@@ -3,11 +3,15 @@ Validators for the fields given.
 """
 
 import io
+import logging
 from email.message import EmailMessage
 
-import mock_vws._cgi as cgi
+import multipart
+
 from mock_vws._query_validators.exceptions import UnknownParameters
 
+_LOGGER = logging.getLogger(__name__)
+
 
 def validate_extra_fields(
     request_headers: dict[str, str],
@@ -27,12 +31,14 @@ def validate_extra_fields(
 
     email_message = EmailMessage()
     email_message["content-type"] = request_headers["Content-Type"]
-    boundary = email_message.get_boundary().encode()
-    parsed = cgi.parse_multipart(fp=body_file, pdict={"boundary": boundary})
-
+    boundary = email_message.get_boundary()
+    assert isinstance(boundary, str)
+    parsed = multipart.MultipartParser(stream=body_file, boundary=boundary)
+    parsed_keys = {item.name for item in parsed.parts()}
     known_parameters = {"image", "max_num_results", "include_target_data"}
 
-    if not parsed.keys() - known_parameters:
+    if not parsed_keys - known_parameters:
         return
 
+    _LOGGER.warning(msg="Unknown parameters are given.")
     raise UnknownParameters
