@@ -3,11 +3,15 @@ Validators for the ``include_target_data`` field.
 """
 
 import io
+import logging
 from email.message import EmailMessage
 
-import mock_vws._cgi as cgi
+import multipart
+
 from mock_vws._query_validators.exceptions import InvalidIncludeTargetData
 
+_LOGGER = logging.getLogger(__name__)
+
 
 def validate_include_target_data(
     request_headers: dict[str, str],
@@ -29,14 +33,22 @@ def validate_include_target_data(
 
     email_message = EmailMessage()
     email_message["content-type"] = request_headers["Content-Type"]
-    boundary = email_message.get_boundary().encode()
-    parsed = cgi.parse_multipart(fp=body_file, pdict={"boundary": boundary})
+    boundary = email_message.get_boundary()
+    assert isinstance(boundary, str)
+    parsed = multipart.MultipartParser(stream=body_file, boundary=boundary)
+
+    parsed_include_target_data = parsed.get("include_target_data")
+    if parsed_include_target_data is None:
+        include_target_data = "top"
+    else:
+        include_target_data = parsed_include_target_data.value
 
-    [include_target_data] = parsed.get("include_target_data", ["top"])
-    lower_include_target_data = include_target_data.lower()
     allowed_included_target_data = {"top", "all", "none"}
-    if lower_include_target_data in allowed_included_target_data:
+    if include_target_data.lower() in allowed_included_target_data:
         return
 
     assert isinstance(include_target_data, str)
+    _LOGGER.warning(
+        msg="The include_target_data field is not an accepted value.",
+    )
     raise InvalidIncludeTargetData(given_value=include_target_data)
