@@ -3,11 +3,15 @@ Validators for the project state.
 """
 
 
+import logging
+
 from mock_vws._database_matchers import get_database_matching_client_keys
 from mock_vws._query_validators.exceptions import InactiveProject
 from mock_vws.database import VuforiaDatabase
 from mock_vws.states import States
 
+_LOGGER = logging.getLogger(__name__)
+
 
 def validate_project_state(
     request_path: str,
@@ -41,4 +45,5 @@ def validate_project_state(
     if database.state != States.PROJECT_INACTIVE:
         return
 
+    _LOGGER.warning(msg="The project is inactive.")
     raise InactiveProject
