@@ -3,10 +3,13 @@ Validators for the active flag.
 """
 
 import json
+import logging
 from http import HTTPStatus
 
 from mock_vws._services_validators.exceptions import Fail
 
+_LOGGER = logging.getLogger(__name__)
+
 
 def validate_active_flag(request_body: bytes) -> None:
     """
@@ -31,4 +34,10 @@ def validate_active_flag(request_body: bytes) -> None:
     if active_flag is None or isinstance(active_flag, bool):
         return
 
+    _LOGGER.warning(
+        msg=(
+            'The value of "active_flag" is not a Boolean or NULL.'
+            "This is not allowed."
+        ),
+    )
     raise Fail(status_code=HTTPStatus.BAD_REQUEST)
