@@ -1,7 +1,7 @@
 """
 Tests for the mock of the query endpoint.
 
-https://library.vuforia.com/articles/Solution/How-To-Perform-an-Image-Recognition-Query.
+https://library.vuforia.com/web-api/vuforia-query-web-api.
 """
 
 from __future__ import annotations
@@ -16,19 +16,17 @@ import time
 import uuid
 from http import HTTPStatus
 from pathlib import Path
-from typing import Any
+from typing import TYPE_CHECKING, Any
 from urllib.parse import urljoin
 from zoneinfo import ZoneInfo
 
 import pytest
 import requests
 from mock_vws._constants import ResultCodes
-from mock_vws.database import VuforiaDatabase
 from PIL import Image
 from requests import Response
 from requests_mock import POST
 from urllib3.filepost import encode_multipart_formdata
-from vws import VWS, CloudRecoService
 from vws.reports import TargetStatuses
 from vws_auth_tools import authorization_header, rfc_1123_date
 
@@ -40,6 +38,10 @@ from tests.mock_vws.utils.assertions import (
     assert_vwq_failure,
 )
 
+if TYPE_CHECKING:
+    from mock_vws.database import VuforiaDatabase
+    from vws import VWS, CloudRecoService
+
 VWQ_HOST = "https://cloudreco.vuforia.com"
 
 _JETTY_CONTENT_TYPE_ERROR = textwrap.dedent(
@@ -297,7 +299,7 @@ class TestContentType:
             timeout=30,
         )
 
-        assert response.text == ""
+        assert not response.text
         assert_vwq_failure(
             response=response,
             status_code=HTTPStatus.UNSUPPORTED_MEDIA_TYPE,
@@ -736,7 +738,7 @@ class TestMaxNumResults:
         This is because uploading 50 images would be very slow.
 
         The documentation at
-        https://library.vuforia.com/articles/Solution/How-To-Perform-an-Image-Recognition-Query
+        https://library.vuforia.com/web-api/vuforia-query-web-api
         states that this must be between 1 and 10, but in practice, 50 is the
         maximum.
         """
@@ -790,7 +792,7 @@ class TestMaxNumResults:
         of the range (1, 50).
 
         The documentation at
-        https://library.vuforia.com/articles/Solution/How-To-Perform-an-Image-Recognition-Query.
+        https://library.vuforia.com/web-api/vuforia-query-web-api.
         states that this must be between 1 and 10, but in practice, 50 is the
         maximum.
         """
@@ -864,7 +866,7 @@ def add_and_wait_for_targets(
     """
     Add targets with the given image.
     """
-    target_ids = set()
+    target_ids: set[str] = set()
     for _ in range(num_targets):
         target_id = vws_client.add_target(
             name=uuid.uuid4().hex,
@@ -1010,7 +1012,7 @@ class TestIncludeTargetData:
     def test_invalid_value(
         high_quality_image: io.BytesIO,
         vuforia_database: VuforiaDatabase,
-        include_target_data: Any,
+        include_target_data: str | bool | int,
     ) -> None:
         """
         A ``BAD_REQUEST`` error is given when a string that is not one of
@@ -1269,7 +1271,7 @@ class TestMaximumImageFileSize:
     ) -> None:  # pragma: no cover
         """
         According to
-        https://library.vuforia.com/articles/Solution/How-To-Perform-an-Image-Recognition-Query.
+        https://library.vuforia.com/web-api/vuforia-query-web-api.
         the maximum file size is "2MiB for PNG".
 
         Above this limit, a ``REQUEST_ENTITY_TOO_LARGE`` response is returned.
@@ -1350,7 +1352,7 @@ class TestMaximumImageFileSize:
     ) -> None:  # pragma: no cover
         """
         According to
-        https://library.vuforia.com/articles/Solution/How-To-Perform-an-Image-Recognition-Query.
+        https://library.vuforia.com/web-api/vuforia-query-web-api.
         the maximum file size is "512 KiB for JPEG".
         However, this test shows that the maximum size for JPEG is 2 MiB.
 
@@ -1546,6 +1548,29 @@ class TestMaximumImageDimensions:
         )
         assert response.text == expected_text
 
+    @staticmethod
+    def test_max_pixels(vuforia_database: VuforiaDatabase) -> None:
+        """
+        No error is returned for an 835 x 835 image.
+        """
+        # If we make this 836 then we hit REQUEST_ENTITY_TOO_LARGE errors.
+        max_height = max_width = 835
+        png_not_too_wide = make_image_file(
+            file_format="PNG",
+            color_space="RGB",
+            width=max_width,
+            height=max_height,
+        )
+
+        image_content = png_not_too_wide.getvalue()
+
+        body = {"image": ("image.jpeg", image_content, "image/jpeg")}
+
+        response = query(vuforia_database=vuforia_database, body=body)
+
+        assert_query_success(response=response)
+        assert response.json()["results"] == []
+
 
 @pytest.mark.usefixtures("verify_mock_vuforia")
 class TestImageFormats:
