@@ -1,9 +1,14 @@
 """
 Tests for the mock of the target list endpoint.
 """
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
 
 import pytest
-from vws import VWS
+
+if TYPE_CHECKING:
+    from vws import VWS
 
 
 @pytest.mark.usefixtures("verify_mock_vuforia")
