@@ -5,20 +5,17 @@ Tests for the mock of the update target endpoint.
 from __future__ import annotations
 
 import base64
-import io
 import json
 import uuid
 from http import HTTPStatus
-from typing import Any, Final
+from typing import TYPE_CHECKING, Any, Final
 from urllib.parse import urljoin
 
 import pytest
 import requests
 from mock_vws._constants import ResultCodes
-from mock_vws.database import VuforiaDatabase
 from requests import Response
 from requests_mock import PUT
-from vws import VWS
 from vws.exceptions.vws_exceptions import BadImage, ProjectInactive
 from vws.reports import TargetStatuses
 from vws_auth_tools import authorization_header, rfc_1123_date
@@ -31,6 +28,12 @@ from tests.mock_vws.utils.assertions import (
 
 _MAX_METADATA_BYTES: Final[int] = 1024 * 1024 - 1
 
+if TYPE_CHECKING:
+    import io
+
+    from mock_vws.database import VuforiaDatabase
+    from vws import VWS
+
 
 def update_target(
     vuforia_database: VuforiaDatabase,
@@ -241,7 +244,7 @@ class TestWidth:
     def test_width_invalid(
         vuforia_database: VuforiaDatabase,
         vws_client: VWS,
-        width: Any,
+        width: int | str | None,
         target_id: str,
     ) -> None:
         """
